@@ -460,11 +460,15 @@ def test_from_search_with_numeric_description():
 
 def test_repr():
     # known ID
-    assert repr(Instrument('IRO1MSMI0001')) == "Instrument('فملی')"
+    assert repr(Instrument('فملی')) == "Instrument('فملی')"
     # unknown ID
     assert repr(Instrument(1)) == "Instrument(1)"
 
 
+def test_equal():
+    assert Instrument('فملی') == Instrument(35425587644337450)
+
+
 @patch_get_content('vsadid_identification.html')
 def test_get_identification():
     assert Instrument(1).get_identification().to_dict() == {1: {
